| Home | Libraries | People | FAQ | More

## Internal tools

Series Evaluation
Arithmetic-Geometric Mean
Continued Fraction Evaluation
Simple Continued Fractions
Centered Continued Fractions
Luroth Expansions
Engel Expansion
Tools For 3-Term Recurrence Relations
Cohen Acceleration
Tuples
Minimax Approximations and the Remez Algorithm
Relative Error and Testing
Graphing, Profiling, and Generating Test Data for Special Functions
Color Maps

Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)